@@ -3,6 +3,7 @@ import convertible
 import inspect
 import traceback
 
+
 def call(func, kwargs):
     argspec = inspect.getargspec(func)
     params = kwargs
@@ -22,10 +23,13 @@ def respond(result, message=None, success=True):
     print(response_json)
 
 
-def run(runner, debug=False):
+def run(runner, debug=False, text=False):
     try:
         data = runner()
-        respond(data)
+        if text:
+            print(data)
+        else:
+            respond(data)
     except Exception, e:
         if debug:
             print '-'*60
@@ -38,4 +42,4 @@ def run(runner, debug=False):
 
 def execute(obj, args):
     method = getattr(obj, args.action)
-    run(lambda: call(method, vars(args)), args.debug)
+    run(lambda: call(method, vars(args)), args.debug, args.text)
